ExoEdge
========

ExoEdge is the Exosite's developed and maintained client to `ExoSense <https://docs.exosite.io>`_. ExoSense provides configuration objects that conform to data schemas. ExoEdge interprets these schema-driven objects and configures industrial IoT gateways to give their data to ExoSense according to schema. ExoEdge is a schema based IIoT gateway that runs on most linux-based platforms.

Requirements
---------------

* Python 3.5+

**NOTE:** In most cases, having a linux gateway is enough as long as the Python requirements are met. ExoEdge is pure-python, which means there is no need for ``gcc`` or ``python-dev`` in order to install and run it.

For information on ExoEdge usage or getting ExoSense for your solution, email `Support <support@exosite.com>`_ or visit `ExoSense <https://docs.exosite.io/exoedge/>`_.
